#!/bin/bash

#_______________________________________________________________________________
#
# script version: 1.1
# date: 2011-06-15
#_______________________________________________________________________________

# exit the script on errors
set -e

CUR_DIR=$(dirname "$0")
CUR_DIR=$(readlink -f -- "$CUR_DIR")

. "$CUR_DIR/config.sh"
. "$BUILDERS_DIR/inc.util.sh"

# prerequisite testing

if [ ! "$(which fakeroot)" ]; then
    echo "Error: you must have fakeroot installed to use this script!"
    exit 1
fi

# we test only for 1 program of debhelper
if [ ! "$(which dh_link)" ]; then
    echo "Error: you must have debhelper installed to use this script!"
    exit 1
fi


adapt_debian_file () {
    if [ ! -f "$1" ]; then
        echo "Error: file $1 doesn't exists!"
        exit 1
    fi
    
    echo "$1 will be adapted"
    
    sed -i "s/@@APP_VERSION@@/$(esc_sed_replace "$APP_VERSION")/g" "$1"
    sed -i "s/@@APP_NAME@@/$(esc_sed_replace "$APP_NAME")/g" "$1"
    sed -i "s/@@APP_DISPLAY_NAME@@/$(esc_sed_replace "$APP_DISPLAY_NAME")/g" "$1"
    sed -i "s/@@DEB_CONTROL_VERSION@@/$(esc_sed_replace "$DEB_CONTROL_VERSION")/g" "$1"
    sed -i "s/@@DEB_CONTROL_SECTION@@/$(esc_sed_replace "$DEB_CONTROL_SECTION")/g" "$1"
    sed -i "s/@@DEB_CONTROL_MAINTAINER@@/$(esc_sed_replace "$DEB_CONTROL_MAINTAINER")/g" "$1"
    sed -i "s/@@DEB_CONTROL_AUTHOR@@/$(esc_sed_replace "$DEB_CONTROL_AUTHOR")/g" "$1"
    sed -i "s/@@DEB_CONTROL_HOMEPAGE@@/$(esc_sed_replace "$DEB_CONTROL_HOMEPAGE")/g" "$1"
    sed -i "s/@@DEB_CONTROL_PACKAGE@@/$(esc_sed_replace "$DEB_CONTROL_PACKAGE")/g" "$1"
    sed -i "s/@@DEB_CONTROL_DESCRIPTION@@/$(esc_sed_replace "$DEB_CONTROL_DESCRIPTION")/g" "$1"
    sed -i "s/@@DEB_CONTROL_EXTRA_DEPENDENCIES@@/$(esc_sed_replace "$DEB_CONTROL_EXTRA_DEPENDENCIES")/g" "$1"
    sed -i "s/@@DEB_MENU_SECTION@@/$(esc_sed_replace "$DEB_MENU_SECTION")/g" "$1"
    sed -i "s/@@DEB_DATE@@/$(esc_sed_replace "$DEB_DATE")/g" "$1"
    sed -i "s/@@DEB_COPYRIGHT@@/$(esc_sed_replace "$DEB_COPYRIGHT")/g" "$1"
    sed -i "s/@@DEB_SHORT_LICENSE@@/$(esc_sed_replace "$DEB_SHORT_LICENSE")/" "$1"
    
    if [ $ARCH_DEPENDENT ]; then
        sed -i "/^Architecture: all.*$/d" "$1"
    fi
    
    if [ $DEB_CONTROL_USE_SHLIBS_DEPENDS ]; then
        sed -i 's/^(Depends: .*)$/\1\$\{shlibs:Depends\}/' "$1"
    fi
    
    echo "file $1 adapted"
}

# re-create the TMP_DIR folder
rm -rfv "$TMP_DIR"
mkdir -v "$TMP_DIR"
printf "\nTMP_DIR $TMP_DIR re-created\n"

#copy the debian folder into TMP_DIR
cp -rv "$DEBIAN_DIR" "$TMP_DIR/debian"
printf "\ndebian dir copied into TMP_DIR\n"

# rename the debian .links file is necessary
if [ ! -f "$TMP_DIR/debian/$APP_NAME.links" \
    -a -f "$TMP_DIR/debian/myapp.links" ]; then
    
    mv "$TMP_DIR/debian/myapp.links" "$TMP_DIR/debian/$APP_NAME.links"
    printf "\n.links file renamed\n"
fi

if [ $OPT_ADAPT_DEBIAN ]; then
    # adapt the $DEB_SHORT_LICENSE, need 4 spaces at the beginning of each line, and
    # NO space at the beginning of the first line
    # As sed doesn't support negative lookahead, we do 2 passes:
    # remove eventual 4 spaces at the beginning of lines
    DEB_SHORT_LICENSE=$(echo "$DEB_SHORT_LICENSE" | sed -r "s/^    //")
    # add 4 spaces to each lines, but the first
    DEB_SHORT_LICENSE=$(echo "$DEB_SHORT_LICENSE" | sed -r "2,$ s/^/    /")

    adapt_debian_file "$TMP_DIR/debian/changelog"
    adapt_debian_file "$TMP_DIR/debian/control"
    adapt_debian_file "$TMP_DIR/debian/menu"
    adapt_debian_file "$TMP_DIR/debian/copyright"
    adapt_debian_file "$TMP_DIR/debian/$APP_NAME.links"
    printf "\nall debian files adapted\n"
fi

# create into TMP_DIR the folder where copy our app
mkdir -pv "$TMP_DIR/debian/$APP_NAME/usr/lib"

# and copy the app
cp -rv "$APP_SRC_DIR" "$TMP_DIR/debian/$APP_NAME/usr/lib/$APP_NAME"
printf "\napp copied\n"

# copy our launcher
cp -v "$LINUX_LAUNCHER" "$TMP_DIR/debian/$APP_NAME/usr/lib/$APP_NAME/$APP_NAME.sh"

# set the launcher as executable
chmod +x "$TMP_DIR/debian/$APP_NAME/usr/lib/$APP_NAME/$APP_NAME.sh"

# create the folder for the desktop file and copy it
mkdir -pv "$TMP_DIR/debian/$APP_NAME/usr/share/applications"
cp -v "$DESKTOP_FILE" \
    "$TMP_DIR/debian/$APP_NAME/usr/share/applications/$APP_NAME.desktop"
printf "\ndesktop file copied and renamed\n"

if [ $OPT_ADAPT_DESKTOP ]; then
    adapt_desktop_file \
        "$TMP_DIR/debian/$APP_NAME/usr/share/applications/$APP_NAME.desktop"
    printf "\ndesktop file adapted\n"
fi

# create the folder and copy our icons
mkdir -pv "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/16x16/apps"
cp -v "$APP_ICON_DIR/icon16.png" \
    "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/16x16/apps/$APP_NAME.png"

mkdir -pv "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/22x22/apps"
cp -v "$APP_ICON_DIR/icon22.png" \
    "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/22x22/apps/$APP_NAME.png"

mkdir -pv "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/32x32/apps"
cp -v "$APP_ICON_DIR/icon32.png" \
    "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/32x32/apps/$APP_NAME.png"

mkdir -pv "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/48x48/apps"
cp -v "$APP_ICON_DIR/icon48.png" \
    "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/48x48/apps/$APP_NAME.png"

mkdir -pv "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/scalable/apps"
cp -v "$APP_ICON_DIR/icon48.svg" \
    "$TMP_DIR/debian/$APP_NAME/usr/share/icons/hicolor/scalable/apps/$APP_NAME.svg"
printf "\nall icons copied\n"

if [ ! -d "$DIST_DIR" ]; then
    mkdir -v "$DIST_DIR"
    printf "\nDIST_DIR $DIST_DIR created\n"
fi

cd "$TMP_DIR"

# clean eventual tempory files
find . -type f -name *.*~ -exec rm {} \;
printf "\nTMP_DIR cleaned\n"

# deb creation
fakeroot dh_link
fakeroot dh_fixperms
fakeroot dh_installdeb
if [ $DEB_CONTROL_USE_SHLIBS_DEPENDS ]; then
    dh_shlibdeps
fi
fakeroot dh_gencontrol
fakeroot dh_md5sums
fakeroot dh_builddeb --destdir="$DIST_DIR"

cd -

printf "\ngenerated files by debhelper:\n"
cat "$TMP_DIR/debian/files"

printf "\ndeb created for $APP_NAME in $DIST_DIR :)\n"
