#!/bin/bash

#_______________________________________________________________________________
#
# script version: 1.1
# date: 2011-06-15
#_______________________________________________________________________________

# exit the script on errors
set -e

CUR_DIR=$(dirname "$0")
CUR_DIR=$(readlink -f -- "$CUR_DIR")

. "$CUR_DIR/config.sh"
. "$BUILDERS_DIR/inc.util.sh"

# prerequisite testing

if [ $OPT_BUILD_MAC_DMG ]; then
    MKISOFS=mkisofs
    if [ ! "$(which "$MKISOFS")" ]; then
        MKISOFS=genisoimage
        if [ ! "$(which "$MKISOFS")" ]; then
            echo "Error: you must have mkisofs or genisoimage installed to build the dmg!"
            exit 1
        fi
    fi
    
    if [ $OPT_COMPRESS_DMG -a ! -x $TOOL_DMG ]; then
        echo "error: the dmg program is missing, the dmg will not be compressed."
        OPT_COMPRESS_DMG=
    fi
fi

adapt_mac_info() {
    if [ ! -f "$1" ]; then
        echo "Error: file $1 doesn't exists!"
        exit 1
    fi
    
    echo "$1 will be adapted"
    
    sed -i "s/@@APP_VERSION@@/$(esc_sed_replace "$APP_VERSION")/g" "$1"
    sed -i "s/@@APP_NAME@@/$(esc_sed_replace "$APP_NAME")/g" "$1"
    sed -i "s/@@APP_DISPLAY_NAME@@/$(esc_sed_replace "$APP_DISPLAY_NAME")/g" "$1"
    
    sed -i "s/@@MAC_BUNDLE_EXECUTABLE@@/$(esc_sed_replace "$MAC_BUNDLE_EXECUTABLE")/g" "$1"
    sed -i "s/@@MAC_BUNDLE_INFOSTRING@@/$(esc_sed_replace "$MAC_BUNDLE_INFOSTRING")/g" "$1"
    sed -i "s/@@MAC_BUNDLE_ICONFILE@@/$(esc_sed_replace "$MAC_BUNDLE_ICONFILE")/g" "$1"
    sed -i "s/@@MAC_BUNDLE_IDENTIFIER@@/$(esc_sed_replace "$MAC_BUNDLE_IDENTIFIER")/g" "$1"
    sed -i "s/@@MAC_BUNDLE_NAME@@/$(esc_sed_replace "$MAC_BUNDLE_NAME")/g" "$1"
    sed -i "s/@@MAC_BUNDLE_SHORTVERSIONSTRING@@/$(esc_sed_replace "$MAC_BUNDLE_SHORTVERSIONSTRING")/g" "$1"
    sed -i "s/@@MAC_BUNDLE_VERSION@@/$(esc_sed_replace "$MAC_BUNDLE_VERSION")/g" "$1"
    
    echo "file $1 adapted"
}

# re-create the TMP_DIR folder
rm -rfv "$TMP_DIR"
mkdir -v "$TMP_DIR"
printf "\nTMP_DIR $TMP_DIR re-created\n"

# create a sub folder which will contains the content of the dmg
DMG="$TMP_DIR/dmg"
mkdir -v "$DMG"

# create the .app folder, so the bundle
BUNDLE="$DMG/$APP_DISPLAY_NAME.app"
mkdir -v "$BUNDLE"

# copy our bundle skeleton
# (our launcher launcher.sh and our symbolic link foxstub are included)
cp -rv "$DMG_SKELET_DIR/." "$BUNDLE/"

# rename the launcher
mv "$BUNDLE/Contents/MacOS/launcher.sh" \
    "$BUNDLE/Contents/MacOS/$MAC_BUNDLE_EXECUTABLE"

# copy our app
cp -rv "$APP_SRC_DIR"/* "$BUNDLE/Contents/MacOS/"

if [ $OPT_ADAPT_MAC_INFO ]; then
    adapt_mac_info "$BUNDLE/Contents/Info.plist"
    
    if [ $MAC_BUNDLE_OVERWRITE_ICON ]; then
        # overwrite the icns icon
        rm -fv "$BUNDLE/Contents/Resources/myapp.icns"
        cp -v "$APP_ICON_DIR/icon.icns" \
            "$BUNDLE/Contents/Resources/$MAC_BUNDLE_ICONFILE.icns"
    fi
fi

# apply the correct permissions
chmod -R 755 "$BUNDLE"

# copy the resulted bundle in DIST_DIR
cp -pRv "$BUNDLE" "$DIST_DIR/"

printf "\nMac bundle for $APP_NAME copied in $DIST_DIR :)\n"

if [ $OPT_BUILD_MAC_DMG ]; then
    if [ $OPT_CUSTOMIZE_DMG ]; then
        if [ $(ls -A "$DMG_CUSTOM_DATA_DIR" | wc -c) -ne 0 ]; then
            cp -Rv "$DMG_CUSTOM_DATA_DIR"/. "$DMG/"
        fi
    fi
    
    cd "$TMP_DIR"
    
    "$MKISOFS" -V "$DMG_VOLNAME" -no-pad -r -apple -o "$DMG_NAME" "$DMG"
    
    if [ $OPT_COMPRESS_DMG ]; then
        # rename temporarily our dmg
        mv "$DMG_NAME" "$DMG_NAME.pre"
        # compress
        "$TOOL_DMG" dmg "$DMG_NAME.pre" "$DMG_NAME"
        rm -fv "$DMG_NAME.pre"
    fi
    
    cd -
    
    # copy the dmg in the DIST_DIR
    cp -v "$TMP_DIR/$DMG_NAME" "$DIST_DIR/"
    
    echo "$DMG_NAME copied in $DIST_DIR"
fi

