#!/bin/bash

#_______________________________________________________________________________
#
# script version: 1.1
# date: 2011-06-15
#_______________________________________________________________________________

# exit the script on errors
set -e

CUR_DIR=$(dirname "$0")
CUR_DIR=$(readlink -f -- "$CUR_DIR")

. "$CUR_DIR/config.sh"
. "$BUILDERS_DIR/inc.util.sh"

# if the app is platform dependent, don't build this multiplatform archive
if [ $ARCH_DEPENDENT ]; then
    echo " This application is platform dependent, so the multiplatform archive will not be built!"
    exit 0
fi

# prerequisite testing

if [ $OPT_BUILD_WIN_XAL -a ! "$(which i586-mingw32msvc-gcc)" ]; then
    echo "Error: you must have MingW32 installed to use this script!"
    exit 1
fi


if [ $OPT_CALC_WINRES_FVERSION ]; then
    WINRES_FILEVERSION=$(win_comma_version "$APP_VERSION")
fi

if [ $OPT_CALC_WINRES_PVERSION ]; then
    WINRES_PRODUCTVERSION=$(win_comma_version "$APP_VERSION")
fi

# re-create the TMP_DIR folder
rm -rfv "$TMP_DIR"
mkdir -v "$TMP_DIR"
printf "\nTMP_DIR $TMP_DIR re-created\n"

# copy our app
cp -rv "$APP_SRC_DIR" "$TMP_DIR/$APP_NAME"

if [ $OPT_BUILD_WIN_XAL ]; then
    # copy the XAL launcher sources
    cp -rv "$XAL_SRC_DIR" "$TMP_DIR/xal"
    # and our icon and resource file
    cp -fv "$APP_ICON_DIR/icon.ico" "$TMP_DIR/xal/$APP_NAME.ico"
    cp -fv "$WIN_RESOURCE" "$TMP_DIR/xal/resource.rc"
    
    if [ $OPT_ADAPT_WINRES ]; then
        adapt_win_resource "$TMP_DIR/xal/resource.rc"
    fi
    
    # build the launcher
    cd "$TMP_DIR/xal/"
    sh build.sh "$APP_NAME" resource.rc
    cd -
    
    # and copy our launchers into this app folder
    cp -v "$TMP_DIR/xal/$APP_NAME.exe" "$TMP_DIR/$APP_NAME/"
    cp -v "$TMP_DIR/xal/xal.bat" "$TMP_DIR/$APP_NAME/$APP_NAME.bat"

    # delete the xal sources
    rm -rv "$TMP_DIR/xal"
fi

# copy the linux launcher
cp -v "$LINUX_LAUNCHER" "$TMP_DIR/$APP_NAME/$APP_NAME.sh"
# and set it as executable
chmod +x "$TMP_DIR/$APP_NAME/$APP_NAME.sh"

# copy the basic Mac OSX launcher
cp -v "$MAC_BASIC_LAUNCHER" "$TMP_DIR/$APP_NAME/$MAC_BASIC_LAUNCHER_NAME"
# and set it as executable
chmod +x "$TMP_DIR/$APP_NAME/$MAC_BASIC_LAUNCHER_NAME"

# create the tar.gz
cd "$TMP_DIR"
tar -zcvf "$DIST_DIR/$TARGZ_NAME.tar.gz" $APP_NAME
cd -

printf "\nmultiplatform $TARGZ_NAME.tar.gz created in $DIST_DIR :)\n"
