#!/bin/bash

#_______________________________________________________________________________
#
# script version: 1.1
# date: 2011-06-15
#_______________________________________________________________________________

# exit the script on errors
set -e

CUR_DIR=$(dirname "$0")
CUR_DIR=$(readlink -f -- "$CUR_DIR")

. "$CUR_DIR/config.sh"
. "$BUILDERS_DIR/inc.util.sh"

# prerequisite testing

if [ ! "$(which rpmbuild)" ]; then
    echo "Error: you must have rpm and rpmbuild installed to use this script!"
    exit 1
fi

adapt_rpm_spec () {
    if [ ! -f "$1" ]; then
        echo "Error: file $1 doesn't exists!"
        exit 1
    fi
    
    echo "$1 will be adapted"
    
    sed -i "s/@@APP_VERSION@@/$(esc_sed_replace "$APP_VERSION")/g" "$1"
    sed -i "s/@@APP_NAME@@/$(esc_sed_replace "$APP_NAME")/g" "$1"
    sed -i "s/@@APP_DISPLAY_NAME@@/$(esc_sed_replace "$APP_DISPLAY_NAME")/g" "$1"
    sed -i "s/@@RPM_VERSION@@/$(esc_sed_replace "$RPM_VERSION")/g" "$1"
    sed -i "s/@@RPM_RELEASE@@/$(esc_sed_replace "$RPM_RELEASE")/g" "$1"
    sed -i "s/@@RPM_RELEASE_SHORT@@/$(esc_sed_replace "$RPM_RELEASE_SHORT")/g" "$1"
    sed -i "s/@@RPM_SUMMARY@@/$(esc_sed_replace "$RPM_SUMMARY")/g" "$1"
    sed -i "s/@@RPM_GROUP@@/$(esc_sed_replace "$RPM_GROUP")/g" "$1"
    sed -i "s/@@RPM_LICENSE@@/$(esc_sed_replace "$RPM_LICENSE")/g" "$1"
    sed -i "s/@@RPM_URL@@/$(esc_sed_replace "$RPM_URL")/g" "$1"
    sed -i "s/@@RPM_SOURCE@@/$(esc_sed_replace "$RPM_SOURCE")/g" "$1"
    sed -i "s/@@RPM_EXTRA_REQUIRES@@/$(esc_sed_replace "$RPM_EXTRA_REQUIRES")/g" "$1"
    sed -i "s/@@RPM_DESCRIPTION@@/$(esc_sed_replace "$RPM_DESCRIPTION")/g" "$1"
    sed -i "s/@@RPM_DATE@@/$(esc_sed_replace "$RPM_DATE")/g" "$1"
    sed -i "s/@@RPM_MAINTAINER@@/$(esc_sed_replace "$RPM_MAINTAINER")/g" "$1"
    
    if [ $ARCH_DEPENDENT ]; then
        sed -i "/^BuildArch:\s*noarch$/d" "$1"
    fi
    
    if [ $RPM_BUILDREQUIRES ]; then
        sed -i "s/#BuildRequires:\s*/BuildRequires: $(esc_sed_replace "$RPM_EXTRA_REQUIRES")/" "$1"
    else
        sed -i "/#BuildRequires:\s*$/d" "$1"
    fi
    
    echo "file $1 adapted"
}

# re-create the TMP_DIR folder
rm -rfv "$TMP_DIR"
mkdir -v "$TMP_DIR"
printf "\nTMP_DIR $TMP_DIR re-created\n"

# create the rpm dirs tree
RPM_DIRS="BUILD RPMS SOURCES SPECS SRPMS"
for DIR in $RPM_DIRS; do
    mkdir -v "$TMP_DIR/$DIR"
done
printf "\nrpm directories created\n"

# copy the spec file
cp -v "$RPM_SPEC_FILE" "$TMP_DIR/$APP_NAME.spec"

if [ $OPT_ADAPT_RPM ]; then
    adapt_rpm_spec "$TMP_DIR/$APP_NAME.spec"
fi

# create a source tar.gz archive for rpmbuild into SOURCES
DUMMY_SRC=$APP_NAME-$RPM_VERSION
mkdir -v "$TMP_DIR/$DUMMY_SRC"
# copy our app
cp -rv "$APP_SRC_DIR" "$TMP_DIR/$DUMMY_SRC/$APP_NAME"
# copy our launcher
cp -v "$LINUX_LAUNCHER" "$TMP_DIR/$DUMMY_SRC/$APP_NAME/$APP_NAME.sh"
# set the launcher as executable
chmod +x "$TMP_DIR/$DUMMY_SRC/$APP_NAME/$APP_NAME.sh"
# create a data subdirectory
mkdir "$TMP_DIR/$DUMMY_SRC/data"
#copy the desktop file
cp -v "$DESKTOP_FILE" "$TMP_DIR/$DUMMY_SRC/data/$APP_NAME.desktop"
if [ $OPT_ADAPT_DESKTOP ]; then
    adapt_desktop_file "$TMP_DIR/$DUMMY_SRC/data/$APP_NAME.desktop"
    printf "\ndesktop file adapted\n"
fi
# and the icons
mkdir -v "$TMP_DIR/$DUMMY_SRC/data/icons"
cp "$APP_ICON_DIR/icon16.png" "$TMP_DIR/$DUMMY_SRC/data/icons/"
cp "$APP_ICON_DIR/icon22.png" "$TMP_DIR/$DUMMY_SRC/data/icons/"
cp "$APP_ICON_DIR/icon32.png" "$TMP_DIR/$DUMMY_SRC/data/icons/"
cp "$APP_ICON_DIR/icon48.png" "$TMP_DIR/$DUMMY_SRC/data/icons/"
cp "$APP_ICON_DIR/icon48.svg" "$TMP_DIR/$DUMMY_SRC/data/icons/"

cd "$TMP_DIR"
# clean eventual tempory files
find . -type f -name *.*~ -exec rm {} \;
tar -zcvf  "$TMP_DIR/SOURCES/$DUMMY_SRC.tar.gz" "$DUMMY_SRC"
cd -

rm -rv "$TMP_DIR/$DUMMY_SRC"

# rmpbuild seems to have a bug, it can't handle a _topdir with whitespace
if [ -n "$(echo "$TMP_DIR" | grep '[ ]')" ]; then
    printf "\nthe path '$TMP_DIR' contains whitespace, rpmbuild will failed. script aborted!\n"
    exit 1
fi

# build the rpm from our spec, specify our local build tree
rpmbuild --define="_topdir $TMP_DIR" -bb "$TMP_DIR/$APP_NAME.spec"

# and finally copy our created rpm in to into the current folder

find "$TMP_DIR/RPMS" -type f -name *.rpm -exec cp {} "$DIST_DIR/" \;

printf "\nrpm created for $APP_NAME in $DIST_DIR :)\n"
