#!/bin/bash

#_______________________________________________________________________________
#
# script version: 1.1
# date: 2011-06-15
#_______________________________________________________________________________

# exit the script on errors
set -e

CUR_DIR=$(dirname "$0")
CUR_DIR=$(readlink -f -- "$CUR_DIR")

. "$CUR_DIR/config.sh"
. "$BUILDERS_DIR/inc.util.sh"

# prerequisite testing

if [ ! "$(which makensis)" ]; then
    echo "Error: you must have makensis (nsis) installed to use this script!"
    exit 1
fi

if [ $OPT_BUILD_WIN_XAL -a ! "$(which i586-mingw32msvc-gcc)" ]; then
    echo "Error: you must have MingW32 installed to use this script!"
    exit 1
fi


adapt_nsis_script () {
    if [ ! -f "$1" ]; then
        echo "Error: file $1 doesn't exists!"
        exit 1
    fi
    
    echo "$1 will be adapted"
    
    sed -i "s/@@APP_VERSION@@/$(esc_sed_replace "$APP_VERSION")/g" "$1"
    sed -i "s/@@APP_NAME@@/$(esc_sed_replace "$APP_NAME")/g" "$1"
    sed -i "s/@@APP_DISPLAY_NAME@@/$(esc_sed_replace "$APP_DISPLAY_NAME")/g" "$1"
    
    sed -i "s/@@NSIS_PRODUCT_NAME@@/$(esc_sed_replace "$NSIS_PRODUCT_NAME")/g" "$1"
    sed -i "s/@@NSIS_PRODUCT_INTERNAL_NAME@@/$(esc_sed_replace "$NSIS_PRODUCT_INTERNAL_NAME")/g" "$1"
    sed -i "s/@@NSIS_PRODUCT_VERSION@@/$(esc_sed_replace "$NSIS_PRODUCT_VERSION")/g" "$1"
    sed -i "s/@@NSIS_PRODUCT_WIN_VERSION@@/$(esc_sed_replace "$NSIS_PRODUCT_WIN_VERSION")/g" "$1"
    sed -i "s/@@NSIS_INSTALLER_NAME@@/$(esc_sed_replace "$NSIS_INSTALLER_NAME")/g" "$1"
    sed -i "s/@@NSIS_LICENCE_NAME@@/$(esc_sed_replace "$NSIS_LICENCE_NAME")/g" "$1"
    
    echo "file $1 adapted"
}

if [ $OPT_CALC_WINRES_FVERSION ]; then
    WINRES_FILEVERSION=$(win_comma_version "$APP_VERSION")
fi

if [ $OPT_CALC_WINRES_PVERSION ]; then
    WINRES_PRODUCTVERSION=$(win_comma_version "$APP_VERSION")
fi

if [ $OPT_CALC_NSIS_WINVERSION ]; then
    NSIS_PRODUCT_WIN_VERSION=$(win_dot_version "$APP_VERSION")
fi

# re-create the TMP_DIR folder
rm -rfv "$TMP_DIR"
mkdir -v "$TMP_DIR"
printf "\nTMP_DIR $TMP_DIR re-created\n"

if [ $OPT_BUILD_WIN_XAL ]; then
    # copy the XAL launcher sources
    cp -rv "$XAL_SRC_DIR" "$TMP_DIR/xal"
    # and our icon and resource file
    cp -fv "$APP_ICON_DIR/icon.ico" "$TMP_DIR/xal/$APP_NAME.ico"
    cp -fv "$WIN_RESOURCE" "$TMP_DIR/xal/resource.rc"
    
    if [ $OPT_ADAPT_WINRES ]; then
        adapt_win_resource "$TMP_DIR/xal/resource.rc"
    fi
    
    # build the launcher
    cd "$TMP_DIR/xal/"
    sh build.sh "$APP_NAME" resource.rc
    cd -
fi

# copy our app
cp -rv "$APP_SRC_DIR" "$TMP_DIR/$APP_NAME"

if [ $OPT_BUILD_WIN_XAL ]; then
    # and copy our launchers into this app folder
    cp -v "$TMP_DIR/xal/$APP_NAME.exe" "$TMP_DIR/$APP_NAME/"
    cp -v "$TMP_DIR/xal/xal.bat" "$TMP_DIR/$APP_NAME/$APP_NAME.bat"

    # delete the xal sources
    rm -rv "$TMP_DIR/xal"
fi

# create the nsis script listing the files to unsinstall
cd "$TMP_DIR/$APP_NAME"
find . -maxdepth 1 -type f > ../uninstall_files.nsi
sed -i -r "s|^\./(.*)$|  Delete \"\$INSTDIR\\\\\1\"|" ../uninstall_files.nsi

# and the list of directory
ls -d */ > ../uninstall_dirs.nsi
sed -i -r "s|^(.*)/$|  RMDir /r \"\$INSTDIR\\\\\1\"|" ../uninstall_dirs.nsi

cd -

# copy the other nsis scripts
cp -rv "$NSIS_SRC_DIR/"* "$TMP_DIR/"

NSIS_SCRIPT="$TMP_DIR/myapp.nsi"
if [ -f "$TMP_DIR/$APP_NAME.nsi" ]; then
    NSIS_SCRIPT="$TMP_DIR/$APP_NAME.nsi"
fi

if [ ! -f "$NSIS_SCRIPT" ]; then
    echo "error: the nsis script is missing!"
    exit 1
fi

if [ $OPT_ADAPT_NSIS ]; then
    adapt_nsis_script "$NSIS_SCRIPT"
fi

# and create the installer
makensis "$NSIS_SCRIPT"

# finally, copy our installer in the root sources dir
cp -v "$TMP_DIR/$NSIS_INSTALLER_NAME" "$DIST_DIR/"

printf "\nWindows installer for $APP_NAME in $DIST_DIR :)\n"
