#!/bin/bash

esc_sed_replace () {
    # replace all new lines by '\n'
    MYVAR=$(echo "$1" | sed -e :a -e '$!N;s/\n/\\\\n/;ta')
    # escape the characters '\', '/'; and '&'
    MYVAR=$(echo "$MYVAR" | sed -e 's/\\/\\\\/g' -e 's/\//\\\//g' -e 's/&/\\\&/g')
    
    echo "$MYVAR"
}

adapt_desktop_file () {
    if [ ! -f "$1" ]; then
        echo "Error: file $1 doesn't exists!"
        exit 1
    fi
    
    echo "$1 will be adapted"
    
    sed -i "s/@@APP_VERSION@@/$(esc_sed_replace "$APP_VERSION")/g" "$1"
    sed -i "s/@@APP_NAME@@/$(esc_sed_replace "$APP_NAME")/g" "$1"
    sed -i "s/@@MOBILE_APP_NAME@@/$(esc_sed_replace "$MOBILE_APP_NAME")/g" "$1"
    sed -i "s/@@APP_DISPLAY_NAME@@/$(esc_sed_replace "$APP_DISPLAY_NAME")/g" "$1"
    sed -i "s/@@MOBILE_APP_DISPLAY_NAME@@/$(esc_sed_replace "$MOBILE_APP_DISPLAY_NAME")/g" "$1"
    sed -i "s/@@APP_DESKTOP_COMMENT@@/$(esc_sed_replace "$APP_DESKTOP_COMMENT")/g" "$1"
    sed -i "s/@@APP_DESKTOP_CATEGORIE@@/$(esc_sed_replace "$APP_DESKTOP_CATEGORIE")/g" "$1"
    sed -i "s/@@APP_DESKTOP_EXTRA@@/$(esc_sed_replace "$APP_DESKTOP_EXTRA")/g" "$1"

    echo "file $1 adapted"
}

adapt_win_resource () {
    if [ ! -f "$1" ]; then
        echo "Error: file $1 doesn't exists!"
        exit 1
    fi
    
    echo "$1 will be adapted"
    
    sed -i "s/@@APP_VERSION@@/$(esc_sed_replace "$APP_VERSION")/g" "$1"
    sed -i "s/@@APP_NAME@@/$(esc_sed_replace "$APP_NAME")/g" "$1"
    sed -i "s/@@APP_DISPLAY_NAME@@/$(esc_sed_replace "$APP_DISPLAY_NAME")/g" "$1"
    
    sed -i "s/@@WINRES_FILEVERSION@@/$(esc_sed_replace "$WINRES_FILEVERSION")/g" "$1"
    sed -i "s/@@WINRES_PRODUCTVERSION@@/$(esc_sed_replace "$WINRES_PRODUCTVERSION")/g" "$1"
    sed -i "s/@@WINRES_Comments@@/$(esc_sed_replace "$WINRES_Comments")/g" "$1"
    sed -i "s/@@WINRES_CompanyName@@/$(esc_sed_replace "$WINRES_CompanyName")/g" "$1"
    sed -i "s/@@WINRES_FileDescription@@/$(esc_sed_replace "$WINRES_FileDescription")/g" "$1"
    sed -i "s/@@WINRES_FileVersion@@/$(esc_sed_replace "$WINRES_FileVersion")/g" "$1"
    sed -i "s/@@WINRES_InternalName@@/$(esc_sed_replace "$WINRES_InternalName")/g" "$1"
    sed -i "s/@@WINRES_LegalCopyright@@/$(esc_sed_replace "$WINRES_LegalCopyright")/g" "$1"
    sed -i "s/@@WINRES_ProductName@@/$(esc_sed_replace "$WINRES_ProductName")/g" "$1"
    sed -i "s/@@WINRES_ProductVersion@@/$(esc_sed_replace "$WINRES_ProductVersion")/g" "$1"
    
    echo "file $1 adapted"
}

# return a version formatted as <int.int.int.int> from a Toolkit version format
# see https://developer.mozilla.org/en/toolkit_version_format
win_dot_version() {
    REGEXP='s/\([0-9]*\)[^.]*\.\([0-9]*\)[^.]*\(\.\([0-9]*\)[^.]*\)\{0,1\}\(\.\([0-9]*\)[^.]*\)\{0,1\}/\1.\2.\4.\6/'
    MYVAR=$(echo $1 | sed $REGEXP)
    MYVAR=$(echo $MYVAR | sed 's/\.\./.0./')
    MYVAR=$(echo $MYVAR | sed 's/\.$/.0/')
    
    echo $MYVAR
}

# return a version formatted as <int,int,int,int> from a Toolkit version format
win_comma_version() {
    MYVAR=$(win_dot_version $1)
    MYVAR=$(echo $MYVAR | sed 's/\./,/g');
    
    echo $MYVAR
}

