/* The MIT License
 * 
 * Copyright (c) 2010 Nicolas Martin <joliclic@gmail.com>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions: * 
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/*
This program allows to launch a XULRunner application with the firefox
executable.

It launches firefox.exe with the -app parameter and the application.ini file
that should be in the same directory than this executable.

If any other parameters has been used (for example -jsconsole), they are passed
to firefox too.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <windows.h>
#include <shlwapi.h>

int fileExists(const char *filename) {
    return GetFileAttributes(filename) != 0xFFFFFFFF;
}

int foxIsInstalled(int multiUsers) {
    HKEY rootKey;
    if (multiUsers) {
        rootKey = HKEY_LOCAL_MACHINE;
    } else {
        rootKey = HKEY_CURRENT_USER;
    }
    
    DWORD dwType;
    char szFoxVersion[32];
    DWORD dwDataSize = 32;
    memset(szFoxVersion , 0, 32);
    
    char foxKey[MAX_PATH] = "SOFTWARE\\Mozilla\\Mozilla Firefox\\";
    
    // open the key for reading.
    HKEY hkeyFOXVer;
    long lResult = RegOpenKeyEx(rootKey,foxKey,0, KEY_READ, &hkeyFOXVer);
    
    if(ERROR_SUCCESS == lResult) {
        // read the version value
        lResult = RegQueryValueEx(hkeyFOXVer, "CurrentVersion", NULL,
                                  &dwType, (BYTE*)szFoxVersion, &dwDataSize);
        
        if(ERROR_SUCCESS == lResult && dwType == REG_SZ) {
            HKEY hkeyFOXPath;
            
            strcat(foxKey, szFoxVersion);
            strcat(foxKey, "\\Main\\");
            
            char  szFoxPath[MAX_PATH];
            memset(szFoxPath, 0, sizeof(MAX_PATH));
            DWORD dwDataSize2 = MAX_PATH;
            
            lResult = RegOpenKeyEx(rootKey, foxKey, 0, KEY_READ, &hkeyFOXPath);
            if (ERROR_SUCCESS == lResult) {
                lResult = RegQueryValueEx(hkeyFOXPath, "PathToExe", NULL,
                                           &dwType, (BYTE*)szFoxPath,
                                           &dwDataSize2);
                
                if(ERROR_SUCCESS == lResult && dwType == REG_SZ) {
                    if (fileExists(szFoxPath)) {
                        return 1;
                    }
                }
            }
        }
    }
    
    return 0;
}

int main(int argc, char **argv) {
    //printf("%i\n", argc);
    //while(argc--)
    //    printf("%s\n", *argv++);
    
    // verify if Firefox is installed
    if (!foxIsInstalled(1) && !foxIsInstalled(0)) {
        MessageBox(0, "Firefox is not installed!\nYou must install Firefox to use this application,\n see http://www.mozilla.com", "Error", MB_OK);
    }
    
    // get the path of the current application
    char appPath[MAX_PATH];
    
    if (!GetModuleFileName(0, appPath, MAX_PATH)) {
        return 1;
    }
    
    char filename[MAX_PATH];
    strcpy(filename, appPath);
    
    // get the directory path of the current executable,
    // i.e. remove the filename from the path
    char *lastSlash = strrchr(appPath, '\\');
    if (!lastSlash)
        return 1;
    *(lastSlash+1) = '\0';
    
    // retrieve the file name from the path
    PathStripPath(filename);
    
    // and remove the eventual extension
    char *lastDot = strrchr(filename, '.');
    if (lastDot)
        *(lastDot) = '\0';
    
    //build the arguments string
    
    char appArgs[MAX_PATH] = "-app \"";
    strcat(appArgs, appPath);
    strcat(appArgs, "application.ini\"");
    
    if (argc > 1) {
        argc--;
        *argv++;
        while(argc--) {
            strcat(appArgs, " ");
            strcat(appArgs, *argv++);
        }
    }
    
    //finally, launch our application.ini with firefox
    ShellExecute (NULL, "open", "Firefox.exe", appArgs, NULL, SW_SHOWNORMAL);
    
    return 0;
}
